# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.agent_connector_system_stats import AgentConnectorSystemStats  # noqa: E501
from agilicus_api.rest import ApiException

class TestAgentConnectorSystemStats(unittest.TestCase):
    """AgentConnectorSystemStats unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AgentConnectorSystemStats
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.agent_connector_system_stats.AgentConnectorSystemStats()  # noqa: E501
        if include_optional :
            return AgentConnectorSystemStats(
                os_version = 'Linux 5.4.0-45-generic #49-Ubuntu SMP Wed Aug 26 13:38:52 UTC 2020 x86_64 GNU/Linux', 
                os_uptime = 45232, 
                agent_uptime = 45000, 
                agent_version = 'v0.29.5 8e4fe7281219aa02dcc088154b7e7e3fc279f259', 
                agent_release_train = 'stable', 
                agent_connector_id = 'SdaAs93adflq3a', 
                agent_connector_org_id = 'd0d4laSDr4ws9'
            )
        else :
            return AgentConnectorSystemStats(
                os_version = 'Linux 5.4.0-45-generic #49-Ubuntu SMP Wed Aug 26 13:38:52 UTC 2020 x86_64 GNU/Linux',
                os_uptime = 45232,
                agent_uptime = 45000,
                agent_version = 'v0.29.5 8e4fe7281219aa02dcc088154b7e7e3fc279f259',
                agent_connector_id = 'SdaAs93adflq3a',
                agent_connector_org_id = 'd0d4laSDr4ws9',
        )

    def testAgentConnectorSystemStats(self):
        """Test AgentConnectorSystemStats"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
